@@ -13,7 +13,7 @@ func TestFormatSize(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
 
 	assert.Equal(t, "1[white:black:-] B", ui.formatSize(1, false, false))
 	assert.Equal(t, "1.0[white:black:-] KiB", ui.formatSize(1<<10, false, false))
@@ -29,7 +29,7 @@ func TestFormatCount(t *testing.T) {
 	defer simScreen.Fini()
 
 	app := testapp.CreateMockedApp(true)
-	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, false, false)
 
 	assert.Equal(t, "1[-::]", ui.formatCount(1))
 	assert.Equal(t, "1.0[-::]k", ui.formatCount(1<<10))
